"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const VDocument_1 = require("../core/VDocument");
const VPage_1 = require("../core/VPage");
const utils_1 = require("./utils");
let vDocument;
let vPage;
utils_1.launch();
beforeAll(async () => {
    vPage = await VPage_1.getVPage({});
});
afterAll(async (done) => {
    vPage.frame
        .browser()
        .close()
        .then(done);
});
beforeEach(async () => {
    await vPage.frame.goto(utils_1.servedFileURL('page.html'));
    vDocument = await VDocument_1.VDocument(vPage.frame, () => document);
});
test('#getSheetDataList()', async () => {
    const result = await vDocument.getSheetDataList();
    expect(result).toEqual([
        { type: 'link', url: utils_1.servedFileURL('main.css') },
        {
            type: 'text',
            url: utils_1.servedFileURL('page.html'),
            text: expect.stringMatching(/\.style-tag/),
        },
    ]);
});
test('#setUuidToIFrames()', async () => {
    await vDocument.setUuidToIFramesAndShadowHosts();
    const uuids = await vPage.frame.$$eval('iframe', els => els.map(el => el.dataset.vanillaClipperIframeUuid));
    expect(uuids).toHaveLength(1);
    expect(uuids[0]).toHaveLength(36);
});
//# sourceMappingURL=VDocument.test.js.map