"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const css_1 = require("../utils/css");
const VDocument_1 = require("./VDocument");
const VJsdom_1 = require("./VJsdom");
exports.VFrame = (frame, isPage) => ({
    frame,
    isPage(frame) {
        frame;
        return isPage;
    },
    initialViewport: null,
    setInitialViewport() {
        if (this.isPage(this.frame)) {
            this.initialViewport = this.frame.viewport();
        }
    },
    async setViewportHeight(height) {
        if (this.isPage(this.frame)) {
            await this.frame.setViewport({ ...this.initialViewport, height });
            await this.frame.waitFor(3000);
        }
    },
    async resetViewport() {
        if (this.isPage(this.frame)) {
            await this.frame.setViewport(this.initialViewport);
        }
    },
    async _clip({ compact = false, element, click, scroll, maxScrolls = 10, }) {
        this.setInitialViewport();
        const originalDocument = await VDocument_1.VDocument(this.frame, () => document);
        const height = await originalDocument.scrollToBottom({ element, scroll, maxScrolls });
        this.setViewportHeight(height);
        if (click) {
            await originalDocument.click(click);
        }
        if (!compact) {
            await originalDocument.setUuidToIFramesAndShadowHosts();
            await originalDocument.replaceObjectURLsWithDataURL();
            await originalDocument.embedContentOfShadowDOMs();
        }
        const { html: originalHTML, location } = await originalDocument.getHTML();
        const sheetDataList = await originalDocument.getSheetDataList();
        const dom = new VJsdom_1.VJsdom(originalHTML, { url: location.href });
        if (element) {
            dom.setElementAsRoot(element);
        }
        dom.execPlugins();
        if (compact) {
            return dom.generate();
        }
        const m = location.href.match(/https:\/\/mobile\.twitter\.com\/.+\/status\/(\d+)/);
        if (m) {
            await dom.embedTwitterVideo(m[1]);
        }
        await Promise.all([
            (async () => {
                const iframes = dom.getIframes();
                const iframeDataList = await originalDocument.clipIframes(iframes);
                dom.embedIFrameContents(iframeDataList);
            })(),
            (async () => {
                await dom.processResourcesInAttrs();
                const sheets = await css_1.extractOrFetchCSS(sheetDataList);
                const optimized = await Promise.all(sheets.map(sheet => css_1.optimizeCSS(sheet, dom.document)));
                dom.appendStyleSheets(optimized);
                dom.appendScriptToHead();
            })(),
        ]);
        await this.resetViewport();
        return dom.generate();
    },
});
//# sourceMappingURL=VFrame.js.map