"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const puppeteer_1 = __importDefault(require("puppeteer"));
const ulid_1 = require("ulid");
const config_store_1 = require("../config-store");
const firebase_1 = require("../utils/firebase");
const mercury_1 = require("../utils/mercury");
const VFrame_1 = require("./VFrame");
const vPageInstances = new Map();
exports.getVPage = async ({ dumpio = false, headless = true, lang = 'ja', device }, forceNew = false) => {
    const key = JSON.stringify({ dumpio, headless, lang, device });
    let vPage = vPageInstances.get(key);
    if (vPage && !forceNew) {
        return vPage;
    }
    const args = ['--no-sandbox', `--lang=${lang}`];
    const browser = await puppeteer_1.default.launch({
        ignoreHTTPSErrors: true,
        dumpio,
        headless,
        args,
    });
    vPage = exports.VPage(await browser.newPage(), await browser.userAgent());
    vPageInstances.set(key, vPage);
    await vPage.frame.setCacheEnabled(false);
    if (device) {
        await vPage.frame.emulate(device);
    }
    return vPage;
};
exports.VPage = (frame, defaultUserAgent) => ({
    ...VFrame_1.VFrame(frame, true),
    defaultUserAgent,
    async save(options) {
        const { url, html } = await this._clip(options);
        const mercury = (await mercury_1.parseMercury(url, html)).getOrElseL(e => {
            throw e;
        });
        if (options.compact) {
            return { url, html, mercury };
        }
        else {
            const id = ulid_1.ulid();
            const path = `pages/${id}.html`;
            const file = firebase_1.bucket.file(path);
            await file.save(html, {
                gzip: true,
                metadata: { contentType: 'text/html' },
            });
            return { url, html, mercury, path };
        }
    },
    async close() {
        return this.frame.close();
    },
    async goto(url, label = 'default') {
        const site = config_store_1.config.findSite(url);
        if (site) {
            await site.login(this, label);
        }
        if (site && site.userAgent) {
            await this.frame.setUserAgent(site.userAgent);
        }
        else {
            await this.frame.setUserAgent(this.defaultUserAgent);
        }
        await this.frame.goto('about:blank', { waitUntil: 'networkidle2' });
        await this.frame.waitFor(500);
        await this.frame.goto(url, { waitUntil: 'networkidle2' });
        await this.frame.waitFor(3000);
    },
});
//# sourceMappingURL=VPage.js.map