"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluespark_1 = require("bluespark");
const firebase_admin_1 = require("firebase-admin");
const tldjs_1 = __importDefault(require("tldjs"));
const article_1 = require("../../../src/models/article");
const firebase_1 = require("../utils/firebase");
const VPage_1 = require("./VPage");
exports.toDocData = (results, compact = false) => {
    const firstResult = results[0];
    const { hostname, domain } = tldjs_1.default.parse(firstResult.url);
    const docBase = {
        createdAt: firebase_admin_1.firestore.FieldValue.serverTimestamp(),
        publishedAt: firstResult.mercury.date_published
            ? bluespark_1.dayjs(firstResult.mercury.date_published)
            : null,
        url: firstResult.url,
        hostname,
        domain,
        texts: results.map(r => r.mercury.content),
        author: firstResult.mercury.author,
        leadImageDownloadUrl: firstResult.mercury.lead_image_url,
        title: firstResult.mercury.title,
        excerpts: results.map(r => r.mercury.excerpt),
    };
    if (compact) {
        return {
            ...docBase,
            type: 'webpageCompact',
        };
    }
    else {
        return {
            ...docBase,
            type: 'webpage',
            downloadUrls: results.map(r => r.path),
        };
    }
};
exports.savePage = async ({ launchOptions, request: { urls, accountLabel, ...options }, }) => {
    const vPage = await VPage_1.getVPage(launchOptions);
    const results = await urls.reduce(async (promise, url) => {
        const prev = await promise;
        await vPage.goto(url, accountLabel);
        const result = await vPage.save(options);
        return [...prev, result];
    }, Promise.resolve([]));
    const docData = exports.toDocData(results, options.compact);
    const doc = article_1.Article.within(firebase_1.db).doc();
    await article_1.Article(doc).set(docData);
    return { doc, docData };
};
//# sourceMappingURL=savePage.js.map