"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const crypto_1 = require("crypto");
const mime_types_1 = require("mime-types");
const p_limit_1 = __importDefault(require("p-limit"));
const config_store_1 = require("../config-store");
const firebase_1 = require("./firebase");
exports.uploadFileFromBuffer = async (buffer, contentType = '') => {
    const hash = crypto_1.createHash('sha512')
        .update(buffer)
        .digest('base64')
        .replace(/\+/g, '-')
        .replace(/\//g, '_')
        .replace(/=/g, '');
    const ext = mime_types_1.extension(contentType);
    const name = ext ? `${hash}.${ext}` : hash;
    const path = `resources/${name}`;
    const run = async () => {
        const file = firebase_1.bucket.file(path);
        const [exists] = await file.exists();
        if (!exists) {
            await file.save(buffer, {
                gzip: true,
                // predefinedAcl: 'publicRead',
                metadata: { contentType },
            });
        }
    };
    return { path, run };
};
exports.batchSaveResources = async (tasks) => {
    const limit = p_limit_1.default(16);
    const urls = [...new Set(tasks.map(task => task.url))];
    const uTasks = urls.map(url => limit(async () => {
        try {
            const relativePath = await exports.saveResource(url);
            if (!relativePath) {
                return;
            }
            tasks.filter(task => task.url === url).forEach(task => task.callback(relativePath));
        }
        catch (err) {
            console.error(err);
        }
    }));
    await Promise.all(uTasks);
};
const cache = new Map();
exports.saveResource = async (url) => {
    const toRelative = (path) => `../${path}`;
    const cached = cache.get(url);
    if (cached && cached.createdAt.diff(rain_1.dayjs(), 'hour') < 1) {
        return toRelative(cached.path);
    }
    const { headers: { 'content-type': contentType, 'content-length': size }, } = await rain_1.got.head(url);
    if (size && parseInt(size) > config_store_1.config.resource.maxSize) {
        return;
    }
    const { body: buffer } = await rain_1.got.get(url, { encoding: null });
    if (!buffer.length || buffer.length > config_store_1.config.resource.maxSize) {
        return;
    }
    const { path, run } = await exports.uploadFileFromBuffer(buffer, contentType);
    cache.set(url, { createdAt: rain_1.dayjs(), path });
    await run();
    return toRelative(path);
};
//# sourceMappingURL=storage.js.map