#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const __1 = require("..");
const utils_1 = require("../utils");
class VanillaClipper extends command_1.Command {
    async run() {
        const { argv: urls, flags } = this.parse(VanillaClipper);
        const { verbose, noSandbox, headless, language, device: deviceName, userDataDir, accountLabel, onlyIndex, element, click, scroll, maxScrolls, } = flags;
        const device = utils_1.devices[deviceName];
        await __1.VBrowser.clipPages({
            verbose,
            noSandbox,
            headless,
            language,
            device,
            userDataDir,
        }, urls.map(url => ({
            url,
            accountLabel,
            onlyIndex,
            element,
            click,
            scroll,
            maxScrolls,
        })));
    }
}
VanillaClipper.strict = false;
VanillaClipper.flags = {
    version: command_1.flags.version(),
    help: command_1.flags.help(),
    verbose: command_1.flags.boolean({
        char: 'v',
        description: 'Verbose',
    }),
    noSandbox: command_1.flags.boolean({
        char: 'n',
        description: 'Launch Puppeteer with --no-sandbox and --disable-setuid-sandbox args',
    }),
    headless: command_1.flags.boolean({
        char: 'h',
        description: 'Headless mode',
        default: true,
    }),
    language: command_1.flags.string({
        char: 'l',
        description: 'Browser language',
    }),
    device: command_1.flags.string({
        description: 'Device name to emulate (Defined in `puppeteer-core/DeviceDescriptors`)',
    }),
    userDataDir: command_1.flags.string({
        char: 'u',
        description: 'Path to User Data Directory',
    }),
    accountLabel: command_1.flags.string({
        char: 'a',
        description: 'Account label',
        default: 'default',
    }),
    onlyIndex: command_1.flags.boolean({
        char: 'i',
        description: 'Save only search index without saving the file',
    }),
    element: command_1.flags.string({
        char: 'e',
        description: 'Selector for the target element (The layout may collapse)',
    }),
    click: command_1.flags.string({
        char: 'c',
        description: 'Selector for the elements to click',
    }),
    scroll: command_1.flags.string({
        char: 's',
        description: 'Selector for the element to scroll to the bottom',
    }),
    maxScrolls: command_1.flags.integer({
        char: 'x',
        description: 'Maximum number of scrolls',
        default: 10,
    }),
};
VanillaClipper.run();
//# sourceMappingURL=vanilla-clipper.js.map