"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const Either_1 = require("fp-ts/lib/Either");
const fs_extra_1 = require("fs-extra");
const trysafe_1 = require("trysafe");
const utils_1 = require("../utils");
const VPage_1 = require("./VPage");
const isTest = process.env.NODE_ENV === 'test';
const puppeteer = require(isTest ? 'puppeteer' : 'puppeteer-core');
class VBrowser {
    constructor(browser) {
        this.browser = browser;
    }
    static async clipPages({ verbose = false, noSandbox = false, headless = true, language, device, userDataDir, }, requests) {
        const vBrowser = await VBrowser.launch(noSandbox, { userDataDir, headless, dumpio: verbose }, language);
        const vPage = await vBrowser.newPage(device);
        const results = [];
        for (let _a of requests.entries()) {
            const [i, _b] = _a, { url, accountLabel } = _b, options = __rest(_b, ["url", "accountLabel"]);
            console.log();
            utils_1.sig.pending('[%d/%d] Clipping %s', i + 1, requests.length, url);
            const result = await trysafe_1.TryAsync(async () => {
                await vPage.goto(url, accountLabel);
                const result = await vPage.clip(options);
                if (result.isLeft()) {
                    throw result.value;
                }
                return result.value;
            });
            results.push(result.mapLeft(l => ({ url })));
            if (result.isLeft()) {
                utils_1.sig.error(result.value);
                continue;
            }
            utils_1.sig.success('Saved as %s', `${result.value._id}.html`);
        }
        await vPage.close();
        await vBrowser.close();
        console.log();
        utils_1.sig.info('Results --------------------------------');
        const succeededCount = results.filter(r => r.isRight()).length;
        if (succeededCount) {
            utils_1.sig.complete('Clipped %d page%s', succeededCount, succeededCount === 1 ? '' : 's');
        }
        results.filter(Either_1.isLeft).forEach(result => utils_1.sig.error('Failed to clip %s', result.value.url));
        return results;
    }
    static async launch(noSandbox = false, _a = {}, lang) {
        var { args = [] } = _a, options = __rest(_a, ["args"]);
        if (lang) {
            args.push(`--lang=${lang}`);
        }
        let executablePath;
        let userDataDir;
        if (!rain_1.is.undefined(options.executablePath)) {
            executablePath = options.executablePath;
            utils_1.sig.info('Using %s', executablePath);
        }
        else {
            executablePath = utils_1.findChrome();
        }
        if (options.userDataDir) {
            userDataDir = options.userDataDir;
            fs_extra_1.ensureDir(userDataDir);
            utils_1.sig.info('User Data Directory: %s', userDataDir);
        }
        const browser = await puppeteer.launch(Object.assign({ ignoreHTTPSErrors: true, executablePath,
            userDataDir }, options, { args: [...args, ...(noSandbox ? utils_1.noSandboxArgs : [])] }));
        return new VBrowser(browser);
    }
    async newPage(device) {
        const vPage = new VPage_1.VPage(this, await this.browser.newPage());
        await vPage.frame.setCacheEnabled(false);
        if (device) {
            await vPage.frame.emulate(device);
        }
        return vPage;
    }
    async close() {
        await this.browser.close();
    }
}
exports.VBrowser = VBrowser;
//# sourceMappingURL=VBrowser.js.map