"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("fp-ts/lib/Either");
const Either_1 = require("fp-ts/lib/Either");
const trysafe_1 = require("trysafe");
const ulid_1 = require("ulid");
const page_1 = require("../../src/models/page");
const config_store_1 = require("../config-store");
const file_1 = require("../utils/file");
const VFrame_1 = require("./VFrame");
class VPage extends VFrame_1.VFrame {
    constructor(vBrowser, frame) {
        super(vBrowser, frame);
        this.vBrowser = vBrowser;
        this.frame = frame;
        this.isRoot = true;
        this.initialViewport = this.frame.viewport();
    }
    async clip(options = {}) {
        const _id = ulid_1.ulid();
        const result = await trysafe_1.TryAsync(() => this._clip(options));
        if (result.isLeft()) {
            return Either_1.left(result.value);
        }
        const { url, html, createdAt } = result.value;
        let filename = null;
        if (!options.onlyIndex) {
            filename = `${_id}.html`;
            await file_1.pagesMainDirectory.file(filename).write(html);
        }
        return await page_1.createPageDoc({ _id, url, html, filename, createdAt });
    }
    async setViewportHeight(height) {
        this.frame.setViewport(Object.assign({}, this.initialViewport, { height }));
    }
    async resetViewport() {
        this.frame.setViewport(this.initialViewport);
    }
    async close() {
        return this.frame.close();
    }
    async goto(url, label = 'default') {
        const site = config_store_1.config.sites.findSite(url);
        if (site) {
            await config_store_1.config.sites.login(site, this, label);
        }
        if (site && site.userAgent) {
            await this.frame.setUserAgent(site.userAgent);
        }
        else {
            await this.frame.setUserAgent(await this.vBrowser.browser.userAgent());
        }
        await this.frame.goto('about:blank', { waitUntil: 'networkidle2' });
        await this.frame.waitFor(500);
        await this.frame.goto(url, { waitUntil: 'networkidle2' });
        await this.frame.waitFor(3000);
    }
}
exports.VPage = VPage;
//# sourceMappingURL=VPage.js.map