"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const fs_extra_1 = require("fs-extra");
const os_1 = require("os");
const ulid_1 = require("ulid");
const page_1 = require("../../src/models/page");
const utils_1 = require("../utils");
const file_1 = require("../utils/file");
const VJsdom_1 = require("./../core/VJsdom");
function exists(dirname) {
    try {
        fs_1.statSync(dirname);
        return true;
    }
    catch (error) {
        return false;
    }
}
async function saveAsV1Page(file) {
    const html = await file.readAsText();
    const dom = new VJsdom_1.VJsdom(html);
    if (!dom.metadata) {
        return;
    }
    const { url, _createdAt } = dom.metadata;
    const _id = ulid_1.ulid();
    const filename = `${_id}.html`;
    await file_1.pagesMainDirectory.file(filename).write(html);
    return await page_1.createPageDoc({
        _id,
        url,
        html,
        filename,
        createdAt: _createdAt.toUTC(),
    });
}
async function main() {
    const oldDataDirectory = file_1.Directory(os_1.homedir()).subdir('.vanilla-clipper');
    utils_1.sig.info('Old data directory: %s', oldDataDirectory.path);
    utils_1.sig.info('New data directory: %s', file_1.dataDirectory.path);
    if (exists(file_1.pagesDirectory.path) || exists(file_1.resourcesDirectory.path)) {
        utils_1.sig.error('"pages" or "resources" directory already exists in new data directory.');
        return;
    }
    fs_extra_1.copyFileSync(oldDataDirectory.file('config.js').path, file_1.configFilePath);
    fs_extra_1.copySync(oldDataDirectory.subdir('resources').path, file_1.resourcesDirectory.path);
    const subdirsInOldPagesDir = oldDataDirectory.subdir('pages').dirList();
    await Promise.all(subdirsInOldPagesDir.map(subdir => Promise.all(subdir.fileList().map(saveAsV1Page))));
}
main().then(() => process.exit());
//# sourceMappingURL=migrate-from-beta.js.map