"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bluespark_1 = require("bluespark");
const types_1 = require("../types");
const Base = bluespark_1.t.type({
    type: bluespark_1.t.string,
    createdAt: bluespark_1.t.union([bluespark_1.DayjsFromFirestoreTimestamp, bluespark_1.FieldValue]),
    publishedAt: bluespark_1.t.union([bluespark_1.DayjsFromFirestoreTimestamp, bluespark_1.t.null]),
    url: bluespark_1.t.string,
    hostname: types_1.stringOrNull,
    domain: types_1.stringOrNull,
    texts: bluespark_1.t.array(bluespark_1.t.string),
    author: types_1.stringOrNull,
    leadImageDownloadUrl: types_1.stringOrNull,
});
const WebpageCompact = bluespark_1.t.type({
    ...Base.props,
    type: bluespark_1.t.literal('webpageCompact'),
    title: bluespark_1.t.string,
    excerpts: bluespark_1.t.union([bluespark_1.t.array(bluespark_1.t.union([bluespark_1.t.string, bluespark_1.t.null])), bluespark_1.t.null]),
});
const Webpage = bluespark_1.t.type({
    ...WebpageCompact.props,
    type: bluespark_1.t.literal('webpage'),
    downloadUrls: bluespark_1.t.array(bluespark_1.t.string),
});
const TweetCompact = bluespark_1.t.type({
    ...Base.props,
    type: bluespark_1.t.literal('tweetCompact'),
    publishedAt: bluespark_1.DayjsFromFirestoreTimestamp,
    tweetId: bluespark_1.t.string,
    retweetCount: bluespark_1.t.number,
    favCount: bluespark_1.t.number,
    imageDownloadUrls: bluespark_1.t.array(bluespark_1.t.string),
    userId: bluespark_1.t.string,
    author: bluespark_1.t.string,
    leadImageDownloadUrl: bluespark_1.t.string,
});
const ArticleCodec = bluespark_1.t.partial({
    ...WebpageCompact.props,
    ...Webpage.props,
    ...TweetCompact.props,
    ...Base.props,
});
exports.Article = bluespark_1.blue('articles', ArticleCodec, [WebpageCompact, Webpage, TweetCompact]);
//# sourceMappingURL=article.js.map