"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTwitterVideoURL = void 0;
const rain_1 = require("@yarnaimo/rain");
const twimo_1 = require("@yarnaimo/twimo");
const config_store_1 = require("../config-store");
async function getTwitterVideoURL(id) {
    const types = new Map([['video', 'video'], ['animated_gif', 'gif']]);
    if (!config_store_1.config.twitter) {
        return;
    }
    const { consumerKey, consumerSecret, token, tokenSecret } = config_store_1.config.twitter;
    const twimo = twimo_1.Twimo({
        consumerKey,
        consumerSecret,
    })({
        token,
        tokenSecret,
    });
    const { extended_entities } = await twimo_1.twget(twimo, 'statuses/show', { id });
    if (!extended_entities ||
        !extended_entities.media ||
        !extended_entities.media[0] ||
        !extended_entities.media[0].video_info ||
        !extended_entities.media[0].video_info.variants) {
        return;
    }
    const { type, video_info: { variants }, } = extended_entities.media[0];
    const largest = variants.sort((a, b) => {
        return (b.bitrate || 0) - (a.bitrate || 0);
    })[0];
    const mediaType = types.get(type);
    if (!mediaType || !rain_1.is.string(largest.url)) {
        return;
    }
    return {
        type: mediaType,
        url: largest.url,
    };
}
exports.getTwitterVideoURL = getTwitterVideoURL;
//# sourceMappingURL=twitter.js.map